//! This module helps us to deal with bounding boxes.

use crate::engine::vector::Vector;

/// This struct represents a bounding box.
#[derive(Copy, Clone)]
pub struct Bbox {
    /// The position of the top right corner of the box.
    pub position: Vector,

    /// The size of the box.
    pub size: Vector,
}

impl Bbox {
    /// Creates a bounding box from x, y, width and height.
    pub fn new(x: f64, y: f64, w: f64, h: f64) -> Bbox {
        Bbox {
            position: Vector::new(x, y),
            size: Vector::new(w, h),
        }
    }

    /// Creates a new bounding box from its center and size.
    pub fn from_center_and_size(center: Vector, size: Vector) -> Bbox {
        Bbox {
            position: center - size / 2.0,
            size,
        }
    }

    /// Returns true is the two bboxes overlap.
    pub fn overlap(self, rhs: Bbox) -> bool {
        rhs.position.x < self.position.x + self.size.x
            && rhs.position.x + rhs.size.x > self.position.x
            && rhs.position.y < self.position.y + self.size.y
            && rhs.position.y + rhs.size.y > self.position.y
    }
}
