//! This module contains objects that are not characters.

use std::time::SystemTime;

use crate::engine::bbox::Bbox;
use crate::engine::texture::{Texture, SPRITE_SIZE};
use crate::engine::vector::Vector;
use crate::engine::Drawable;

/// An object that can collide with the character.
pub struct Object {
    /// The initial position of the object.
    pub position: Vector,
}

impl Object {
    /// Creates a new object.
    pub fn new(position: Vector) -> Object {
        Object { position }
    }
}

impl Drawable for Object {
    fn texture(&self) -> Texture {
        Texture::Overworld
    }

    fn texture_rect(&self, _now: SystemTime) -> Bbox {
        Bbox::new(46.0 * SPRITE_SIZE, 0.0, SPRITE_SIZE, SPRITE_SIZE)
    }

    fn position(&self) -> Vector {
        self.position
    }
}
